<p align="center">
<a href="https://github.com/Dhruv9449">
	<img src="https://github.com/user-attachments/assets/436d2707-e79e-41d8-b1d0-fa2d2948307e" alt="Dhruv Shah" height=200/>
</a>
	<h2 align="center"> Tizori CLI 🔐</h2>
	<h4 align="center"> Client-side CLI tool for self-hosted credentials manager with role-based access control (RBAC).</h4>
</p>

<span align="center">

<a href="https://www.python.org/"><img src="https://img.shields.io/badge/built%20with-Python3-blue.svg" alt="built with Python3" /></a>
<a href="https://badge.fury.io/py/tizori-cli"><img src="https://img.shields.io/pypi/v/tizori-cli?color=blue&label=pypi%20package" alt="PyPI version" height="18"></a>

</span>

## Table of Contents
- [Key Features](#key-features)
- [Tech Stack and Dependencies](#tech-stack-and-dependencies)
- [Preview](#preview)
- [Setting-up and Installation](#setting-up-and-installation)
- [Usage](#usage)
- [Developer](#developer)


<br>

## Key Features
- [x] Ability to login and create user accounts
- [x] Manage roles and permissions through CLI
- [x] Manage applications and credentials through CLI
- [x] Manage users and roles through CLI

<br>
<br>

## Tech Stack and Dependencies
- [Python 3.12](https://www.python.org/downloads/release/python-3120/)
- [Poetry](https://python-poetry.org/)
- [Typer](https://typer.tiangolo.com/)

<br>
<br>

## Preview
![Tizori CLI](./assets/preview.png)

<br>
<br>

## Installation
### Using pip/pipx
Use the following command to install the CLI application -

```zsh
pip install tizori-cli
```
or
```zsh
pipx install tizori-cli
```

<br>
<br>


## Usage

Use the following command for help -
```zsh
tizori --help
```

<br>
<br>

## Developer

<table>
	<tr align="center">
		<td>
		Dhruv Shah
		<p align="center">
			<img src = "https://avatars.githubusercontent.com/u/88224695" width="150" height="150" alt="Dhruv Shah">
		</p>
			<p align="center">
				<a href = "https://github.com/Dhruv9449">
					<img src = "http://www.iconninja.com/files/241/825/211/round-collaboration-social-github-code-circle-network-icon.svg" width="36" height = "36" alt="GitHub"/>
				</a>
				<a href = "https://www.linkedin.com/in/Dhruv9449" target="_blank">
					<img src = "http://www.iconninja.com/files/863/607/751/network-linkedin-social-connection-circular-circle-media-icon.svg" width="36" height="36" alt="LinkedIn"/>
				</a>
				<a href = "mailto:dhruvshahrds@gmail.com" target="_blank">
					<img src = "https://www.iconninja.com/files/312/807/734/share-send-email-chat-circle-message-mail-icon.svg" width="36" height="36" 
					alt="Email"/>
				</a>
			</p>
		</td>
	</tr>
</table>

<p align="center">
	Made with ❤️ by <a href="https://github.com/Dhruv9449">Dhruv Shah</a>
</p>